netapp_ontap.models.datacollection_version_data_collection API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.datacollection_version_data_collection`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DatacollectionVersionDataCollectionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DatacollectionVersionDataCollection object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `create_time: ImpreciseDateTime GET`

    The creation time of the data collection version.

    Example: 2018-06-04T19:00:00.000+0000

  `description: str GET`

    Description of the data collection.

    Example: This is an example data collection.

  `embedding: DatacollectionVersionDataCollectionEmbedding GET`

    Vectorization settings for the data collection.

  `entities: List[DatacollectionEntities] GET`

    List of entities.

  `entity_count: Size GET`

    The count of entities in a data collection.

    Example: 1000

  `errors: List[DataEngineEntityErrors] GET`

    The errors field of the datacollection_version_data_collection.

  `last_refresh_time: ImpreciseDateTime GET`

    The last refresh time of the data collection. This field is generated when the data collection is refreshed.

    Example: 2018-06-04T19:00:00.000+0000

  `message: str GET`

    The message associated with the current state of the data collection.

    Example: creating data collection

  `name: str GET`

    Name of the data collection.

    Example: Example Data Collection

  `owner: str GET`

    The owner of the data collection.

    Example: Eva

  `query: DatacollectionQuery GET`

    The query selector associated with the data collection.

  `size: Size GET`

    The size of the data collection, in bytes.

    Example: 1000

  `state: str GET`

    State of the data collection version:

    - draft - The data collection is in draft.
    - processing - The data collection is being processed.
    - published - The data collection is published.
    - failed - The data collection has a failure.
    - outdated - The data collection is outdated.
    - Valid in GET requests.

    Valid choices:

    - draft
    - processing
    - published
    - failed
    - outdated
  `type: str GET`

    The type of the data collection.

    - manual - The data collection is created by providing an entities list.
    - dynamic - The data collection is created with a query selector.

    Valid choices:

    - manual
    - dynamic
  `uuid: str GET`

    Unique identifier of the data collection.

    Example: 123e4567-e89b-12d3-a456-426614174000

  `version: DatacollectionVersionDataCollectionVersion GET`

    The version information of a data collection.

  `workspace: Workspace GET`

    Workspace containing the data collection.